@@ -1,6 +1,6 @@
 package Config::Find::Any;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use strict;
 use warnings;
@@ -26,7 +26,7 @@ sub _find {
         return $fn if defined $fn;
     }
 
-    return;
+    return undef;
 }
 
 sub _open {
